@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: mysql.py 1006 2010-07-07 21:03:57Z pronovic $
+# Revision : $Id: mysql.py 1022 2011-10-11 23:27:49Z pronovic $
 # Purpose  : Provides an extension to back up MySQL databases.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -129,7 +129,7 @@ class MysqlConfig(object):
    @sort: __init__, __repr__, __str__, __cmp__, user, password, all, databases
    """
 
-   def __init__(self, user=None, password=None, compressMode=None, all=None, databases=None):  # pylint: disable-msg=W0622
+   def __init__(self, user=None, password=None, compressMode=None, all=None, databases=None):  # pylint: disable=W0622
       """
       Constructor for the C{MysqlConfig} class.
       
