@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 1088 2014-10-08 00:19:58Z pronovic $
+# Revision : $Id: release.py 1099 2015-01-05 20:49:18Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2011,2013,2014"
-VERSION     = "2.24.1"
-DATE        = "07 Oct 2014"
+COPYRIGHT   = "2004-2011,2013-2015"
+VERSION     = "2.24.2"
+DATE        = "05 Jan 2015"
 URL         = "http://cedar-backup.sourceforge.net/"
 
