@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Tools
-# Revision : $Id: __init__.py 998 2010-07-07 19:56:08Z pronovic $
+# Revision : $Id: __init__.py 1083 2014-10-07 19:17:12Z pronovic $
 # Purpose  : Provides package initialization
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -45,5 +45,5 @@ the util/ directory.
 # Using 'from CedarBackup2.tools import *' will just import the modules listed
 # in the __all__ variable.
 
-__all__ = [ 'span', ]
+__all__ = [ 'span', 'amazons3', ]
 
